summaryrefslogtreecommitdiff
path: root/src/lib/subtitle_decoder.cc
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2016-06-10 11:26:07 +0100
committerCarl Hetherington <cth@carlh.net>2016-06-10 11:26:07 +0100
commit7ecfc2b34b0c50f1859e70287fd7e5bfc0c50ce4 (patch)
treee706114fa524e6772126575f1ca7eb02e9a0ba86 /src/lib/subtitle_decoder.cc
parente69de121d28bd4ebe55b06123fa340c19838cd19 (diff)
Tweak subrip position.
Diffstat (limited to 'src/lib/subtitle_decoder.cc')
-rw-r--r--src/lib/subtitle_decoder.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/lib/subtitle_decoder.cc b/src/lib/subtitle_decoder.cc
index 2866dee5c..d210c578f 100644
--- a/src/lib/subtitle_decoder.cc
+++ b/src/lib/subtitle_decoder.cc
@@ -160,10 +160,10 @@ SubtitleDecoder::give_text (ContentTimePeriod period, sub::Subtitle const & subt
dcp::VAlign v_align;
if (needs_placement) {
DCPOMATIC_ASSERT (i.vertical_position.line);
/* This 0.122 is an arbitrary value to lift the bottom sub off the bottom
of the screen a bit to a pleasing degree.
*/
- v_position = 0.122 + i.vertical_position.line.get() * 1.2 * j.font_size.proportional (72 * 11);
+ v_position = 0.053 + i.vertical_position.line.get() * 1.2 * j.font_size.proportional (72 * 11);
v_align = dcp::VALIGN_BOTTOM;
} else {
DCPOMATIC_ASSERT (i.vertical_position.proportional);
@@ -160,10 +160,10 @@ SubtitleDecoder::give_text (ContentTimePeriod period, sub::Subtitle const & subt
if (needs_placement) {
DCPOMATIC_ASSERT (i.vertical_position.line);
- /* This 0.122 is an arbitrary value to lift the bottom sub off the bottom
+ /* This 0.053 is an arbitrary value to lift the bottom sub off the bottom
of the screen a bit to a pleasing degree.
*/